Skip to contents

Retrieves media item information for one or more milestones from the mediaitem table, which contains the mid field directly (no linking table needed).

Usage

get_milestone_media(mid)

Arguments

mid

A numeric vector of milestone IDs

Value

A data frame with columns from the mediaitem table, including mid, miid, type, url, title, caption, source, and type2

Examples

if (FALSE) { # \dontrun{
# Get media items for a single milestone
get_milestone_media(53)

# Get media items for multiple milestones
get_milestone_media(c(53, 54, 55))
} # }