Skip to contents

Retrieves reference information for one or more milestones by joining the milestone2reference linking table with the reference table.

Usage

get_milestone_references(mid)

Arguments

mid

A numeric vector of milestone IDs

Value

A data frame with columns from both milestone2reference and reference tables, including mid, rid, and all reference fields (author, title, year, etc.)

Examples

if (FALSE) { # \dontrun{
# Get references for a single milestone
get_milestone_references(53)

# Get references for multiple milestones
get_milestone_references(c(53, 54, 55))
} # }