Skip to contents

Retrieve the keyword table containing keywords or terms attached to milestone items as a freeform classification.

Usage

keyword()

Format

A data frame. See keyword() for details.

Value

A data frame with 335 rows and 2 variables:

kid

keyword id, a numeric vector

name

keyword name, a character vector

Details

This is a freeform classification listing keywords or terms attached to milestone items. Use milestone2keyword() to link milestones to their keywords.

Examples

if (FALSE) { # \dontrun{
# Get all keywords
kw <- keyword()

# Find keywords containing "chart"
library(dplyr)
kw |> filter(grepl("chart", name, ignore.case = TRUE))
} # }