Skip to contents

Retrieve the subject table containing subject classifications that indicate the substantive context of milestone events.

Usage

subject()

Format

A data frame. See subject() for details.

Value

A data frame with 4 rows and 2 variables:

sid

subject id, a numeric vector

name

subject name (Physical, Mathematical, Human, Other), a character vector

Details

The subject classification indicates the substantive context of the milestone event. Use milestone2subject() to link milestones to their subjects.

Examples

if (FALSE) { # \dontrun{
# Get all subjects
subj <- subject()
} # }