Retrieve the aspect table containing aspect classifications that indicate
the role milestone events played in the history of data visualization.
Value
A data frame with 4 rows and 2 variables:
- asid
aspect id, a numeric vector
- name
aspect name (Cartography, Statistics & Graphics, Technology, Other), a character vector
Details
The aspect classification indicates the role an event played in the history
of data visualization. Use milestone2aspect() to link milestones
to their aspects.