Retrieves author information for one or more milestones by joining the milestone2author linking table with the author table.
Value
A data frame with columns from both milestone2author and author tables, including mid, aid, and all author fields (prefix, givennames, lname, etc.)
Examples
if (FALSE) { # \dontrun{
# Get authors for a single milestone
get_milestone_authors(53)
# Get authors for multiple milestones
get_milestone_authors(c(53, 54, 55))
} # }