Retrieve the keyword table containing keywords or terms attached to
milestone items as a freeform classification.
Value
A data frame with 335 rows and 2 variables:
- kid
keyword id, a numeric vector
- name
keyword name, a character vector
Details
This is a freeform classification listing keywords or terms attached to
milestone items. Use milestone2keyword() to link milestones
to their keywords.