The reference table gives the references associated with milestones items
A dataset containing bibliographic references associated with milestone events.
Format
A data frame with 352 rows and 17 variables:
- rid
reference id, a numeric vector
- type
reference type (article, book, incollection), a factor
- author
author names, a character vector
- title
title of publication, a character vector
- journal
journal name (for articles), a character vector
- month
month of publication, a character vector
- year
year of publication, a character vector
- volume
volume number, a character vector
- number
issue number, a character vector
- pages
page numbers, a character vector
- publisher
publisher name, a character vector
- address
publisher address, a character vector
- editor
editor names, a character vector
- booktitle
book title (for incollection), a character vector
- bibtexkey
BibTeX key, a character vector
- abstract
abstract, a character vector
- note
notes, a character vector
Details
The fields in the reference table are:
ridreference id, a numeric vector
typereference type, a factor with levels
articlebookincollectionauthorauthor, a character vector
titletitle of publication, a character vector
journaljournal name, for an
article, character vectormonthmonth name, a character vector
yeara numeric vector
volumea character vector
numbera character vector
pagesa character vector
publishera character vector
addressa character vector
editora character vector
booktitlea character vector
bibtexkeyBibTeX key used in the source .bib files, a character vector
abstracta character vector
notea character vector
In the note field, Loc{} refers to a library catalog identifier, e.g, Loc{BL: IA 3Q024}
TODO: need a function to turn these back to BibTeX